==> hyades.source_1.0.4_20040129_1710.zip: org/eclipse/hyades/trace/ui/internal/actions/DetachActionDelegate.java <==
/**********************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/

package org.eclipse.hyades.trace.ui.internal.actions;

import org.eclipse.hyades.internal.execution.local.control.Agent;
import org.eclipse.hyades.internal.execution.local.control.Node;
import org.eclipse.hyades.loaders.util.LoadersUtils;
import org.eclipse.hyades.models.hierarchy.TRCAgentProxy;
import org.eclipse.hyades.models.hierarchy.TRCProcessProxy;
import org.eclipse.hyades.trace.internal.ui.PDProjectExplorer;
import org.eclipse.hyades.trace.internal.ui.TraceConstants;
import org.eclipse.hyades.trace.ui.ProfileEvent;
import org.eclipse.hyades.trace.ui.UIPlugin;
import org.eclipse.hyades.trace.ui.internal.piclient.XMLTraceDataProcessor;
import org.eclipse.hyades.trace.ui.internal.util.DetachWarningDialog;
import org.eclipse.hyades.trace.ui.internal.util.PDCoreUtil;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.window.Window;


public class DetachActionDelegate extends AbstractListenerActionDelegate {
 
    /**
     * @see AbstractProfileActionDelegate#doAction(Object)
     */
    public void doAction(Object object) throws Exception {
        if ((object == null) || !(object instanceof TRCAgentProxy)) {
            return;
        }

        PDProjectExplorer fViewer = UIPlugin.getDefault().getViewer();

        if (fViewer == null) {
            MessageDialog.openInformation(UIPlugin.getActiveWorkbenchShell(), "Title", "Action not available in current context");

            return;
        }

        run((TRCAgentProxy) object, fViewer);
    }

    public void run(TRCAgentProxy agent, PDProjectExplorer fViewer) {		
		if (agent.isMonitored() && UIPlugin.getDefault().getPreferenceStore().getBoolean(TraceConstants.PROFILE_TIPS))
		{
			DetachWarningDialog infodialog = new DetachWarningDialog(UIPlugin.getDefault().getViewer().getShell(), UIPlugin.getResourceString("PROFILING_TIP_TITLE"));
			if (infodialog.open()==Window.CANCEL) return;		
		}

        TRCProcessProxy process = agent.getProcessProxy();
        String hostName = process.getNode().getName();
        try {
            Node node = PDCoreUtil.profileConnect(hostName, String.valueOf(process.getNode().getPort()));

            if (node != null) {
            	
				Object instance = LoadersUtils.locateAgentInstance(agent);
				if(instance != null && instance instanceof Agent)
				{
					Agent a = (Agent)instance;
                    if (a.isAttached()) {
                        a.detach();
                    }
                }
            }

            agent.setMonitored(false);
            agent.setAttached(false);
			LoadersUtils.deregisterDataProcessor(agent);

            if (agent.isToProfileFile()) {
                XMLTraceDataProcessor processor = (XMLTraceDataProcessor) LoadersUtils.locateDataProcessor(agent);

                if (processor != null) {
                    processor.endTrace(processor.getFileWriter());
                    processor.setProfileFileName(null);
                    processor.setProfilingFile(null);
                    processor.setFileWriter(null);
                }
            }

            ProfileEvent event = UIPlugin.getDefault().getProfileEvent();

            event.setSource(agent);
            event.setType(ProfileEvent.DETACH);

            UIPlugin.getDefault().notifyProfileEventListener(event);
        } catch (Exception exc) {
            exc.printStackTrace();
        }
    }

    /**
     * @see AbstractProfileActionDelegate#isEnabledFor(Object)
     */
    protected boolean isEnabledFor(Object element) {
        if ((element != null) && (element instanceof TRCAgentProxy) && ((TRCAgentProxy) element).isAttached()) {
            return true;
        }

        return false;
    }

    /**
     * @see AbstractProfileActionDelegate#enableForMultiSelection()
     */
    protected boolean enableForMultiSelection() {
        return false;
    }
}

==> hyades.source_1.1.0_20030930_2244.zip: org/eclipse/hyades/trace/ui/internal/actions/DetachActionDelegate.java <==
/**********************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/

package org.eclipse.hyades.trace.ui.internal.actions;

import org.eclipse.hyades.models.hierarchy.TRCAgentProxy;
import org.eclipse.hyades.trace.internal.ui.PDProjectExplorer;
import org.eclipse.hyades.trace.ui.ProfileEvent;
import org.eclipse.hyades.trace.ui.UIPlugin;
import org.eclipse.hyades.trace.ui.internal.util.PDCoreUtil;
import org.eclipse.jface.dialogs.MessageDialog;


public class DetachActionDelegate extends AbstractListenerActionDelegate {
 
    /**
     * @see AbstractProfileActionDelegate#doAction(Object)
     */
    public void doAction(Object object) throws Exception {
        if ((object == null) || !(object instanceof TRCAgentProxy)) {
            return;
        }

        PDProjectExplorer fViewer = UIPlugin.getDefault().getViewer();

        if (fViewer == null) {
            MessageDialog.openInformation(UIPlugin.getActiveWorkbenchShell(), "Title", "Action not available in current context");

            return;
        }

        run((TRCAgentProxy) object, fViewer);
    }

    public void run(TRCAgentProxy agent, PDProjectExplorer fViewer) {		
//		if (agent.isMonitored() && UIPlugin.getDefault().getPreferenceStore().getBoolean(TraceConstants.PROFILE_TIPS))
//		{
//			DetachWarningDialog infodialog = new DetachWarningDialog(UIPlugin.getDefault().getViewer().getShell(), UIPlugin.getResourceString("PROFILING_TIP_TITLE"));
//			if (infodialog.open()==Window.CANCEL) return;		
//		}

        try {
			PDCoreUtil.detachAgent(agent);

            ProfileEvent event = UIPlugin.getDefault().getProfileEvent();

            event.setSource(agent);
            event.setType(ProfileEvent.DETACH);

            UIPlugin.getDefault().notifyProfileEventListener(event);
        } catch (Exception exc) {
            exc.printStackTrace();
        }
    }


    /**
     * @see AbstractProfileActionDelegate#isEnabledFor(Object)
     */
    protected boolean isEnabledFor(Object element) {
        if ((element != null) && (element instanceof TRCAgentProxy) && ((TRCAgentProxy) element).isAttached()) {
            return true;
        }

        return false;
    }

    /**
     * @see AbstractProfileActionDelegate#enableForMultiSelection()
     */
    protected boolean enableForMultiSelection() {
        return false;
    }
}
